==> lowcode-editor-skeleton-2.0.5.tgz: package/es/components/settings/settings-from/index.js <==
import React, { useMemo } from 'react';
import { createForm, onFieldValueChange } from '@formily/core';
import cls from 'classnames';
import { Form } from '@formily/antd-v5';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
export function SettingsForm(_ref) {
  var className = _ref.className,
    style = _ref.style,
    settings = _ref.settings,
    SchemaField = _ref.SchemaField,
    schema = _ref.schema;
  var formWrapperCls = usePrefixCls('settings-form-wrapper');
  var form = useMemo(function () {
    var values = settings.getValue();
    console.log('---initialValues', settings.getNode().componentMeta.configure.values());
    return createForm({
      // initialValues: field.getNode().componentMeta.configure.values(),
      values: values,
      effects: function effects() {
        onFieldValueChange('*', function (field) {
          var value = field.value;
          var key = field.path.toString();
          console.log('---value', field, key, value, '---');
          settings.setPropValue(key, value);
        });
        // onFormValuesChange(
        //   debounce((form) => {
        //     const values = form.values;
        //     console.log('---values', values, '---');
        //     field.getNode().setProps(values);
        //   }, 150),
        // );
      }
    });
  }, [settings]);
  return /*#__PURE__*/React.createElement(Form, {
    className: cls('lc-settings-form', formWrapperCls, className),
    form: form,
    style: style
  }, /*#__PURE__*/React.createElement(SchemaField, {
    schema: schema
  }));
}

==> lowcode-editor-skeleton-2.0.6.tgz: package/es/components/settings/settings-from/index.js <==
import React, { useMemo } from 'react';
import { createForm, onFieldValueChange } from '@formily/core';
import cls from 'classnames';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { Form, SchemaField } from './schema-field';
export function SettingsForm(_ref) {
  var className = _ref.className,
    style = _ref.style,
    settings = _ref.settings,
    schema = _ref.schema,
    components = _ref.components,
    scope = _ref.scope;
  var formWrapperCls = usePrefixCls('settings-form-wrapper');
  var form = useMemo(function () {
    var values = settings.getValue();
    console.log('---initialValues', settings.getNode().componentMeta.configure.values());
    return createForm({
      // initialValues: field.getNode().componentMeta.configure.values(),
      values: values,
      effects: function effects() {
        onFieldValueChange('*', function (field) {
          var value = field.value;
          var key = field.path.toString();
          console.log('---value', field, key, value, '---');
          settings.setPropValue(key, value);
        });
        // onFormValuesChange(
        //   debounce((form) => {
        //     const values = form.values;
        //     console.log('---values', values, '---');
        //     field.getNode().setProps(values);
        //   }, 150),
        // );
      }
    });
  }, [settings]);
  console.log('---components', components, scope, SchemaField);
  return /*#__PURE__*/React.createElement(Form, {
    className: cls('lc-settings-form', formWrapperCls, className),
    form: form,
    style: style,
    feedbackLayout: "terse",
    colon: false
  }, /*#__PURE__*/React.createElement(SchemaField, {
    schema: schema,
    components: components,
    scope: scope
  }));
}
